﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using HLWebOKBAdminPlugin.OKBAdministrationService;
using HLWebOKBAdminPlugin.Helpers;

namespace HLWebOKBAdminPlugin.Models {
    public class AdminModel {
        //member var
        private IList<AlgorithmClass> algorithmClassList;


        public String SelectedSubMenu { get; set; }
        public IList<AlgorithmClass> AlgorithmClassProp { get { return algorithmClassList; } set { ;} }

        //***************************************Algorithm Class********************************************
        //get all algorithm classes
        public IList<AlgorithmClass> AlgorithmClassGetAll() {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            algorithmClassList = new List<AlgorithmClass>();

            if (adminClient != null) {
                AlgorithmClass[] algorithmClasses = adminClient.GetAlgorithmClasses();
                foreach (AlgorithmClass ac in algorithmClasses) {
                    algorithmClassList.Add(ac);

                }
            }//if (adminClient != null)

            return algorithmClassList;
        }//AlgorithmClassGetAll

        public long AddAlgorithmClass(string name, string description) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                AlgorithmClass ac = new AlgorithmClass();
                ac.Description = description;
                ac.Name = name;

                return adminClient.AddAlgorithmClass(ac);
            }

            return 0;
        }//AddAlgorithmClass

        public void DeleteAlgorithmClass(long id) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null){
                adminClient.DeleteAlgorithmClass(id);
            }
        }//DeleteAlgorithmClass

        public void UpdateAlgorithmClass(long id, string name, string description) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                AlgorithmClass ac = adminClient.GetAlgorithmClass(id);

                if (ac != null) {
                    ac.Id = id;
                    ac.Name = name;
                    ac.Description = description;

                    adminClient.UpdateAlgorithmClass(ac);
                }
            }
        }//UpdateAlgorithmClass

        //***************************************Algorithms*************************************************
        //get all algorithms
        public IList<Algorithm> AlgorithmsGetAll() {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            IList<Algorithm> algorithmList = new List<Algorithm>();

            if (adminClient != null) {
                Algorithm[] algorithm = adminClient.GetAlgorithms();
                foreach (Algorithm al in algorithm) {
                    algorithmList.Add(al);

                }
            }//if (adminClient != null)

            return algorithmList;
        }//AlgorithmsGetAll

        public long AddAlgorithm(string name, string description, string dataTypeName, string dataTypeTypeName) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                Algorithm al = new Algorithm();
                al.DataTypeName = dataTypeName;
                al.DataTypeTypeName = dataTypeTypeName; 
                al.Description = description; 
                al.Name = name;

                return adminClient.AddAlgorithm(al);
            }

            return 0;
        }//AddAlgorithm

        public void DeleteAlgorithm(long id) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                adminClient.DeleteAlgorithm(id);
            }
        }//DeleteAlgorithm

        public void UpdateAlgorithm(long id, string name, string description, string dataTypeName, string dataTypeTypeName) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                Algorithm al = adminClient.GetAlgorithm(id);

                if (al != null){
                    al.DataTypeName = dataTypeName;
                    al.DataTypeTypeName = dataTypeTypeName;
                    al.Description = description;
                    al.Name = name;

                    adminClient.UpdateAlgorithm(al);
                }
            }
        }//UpdateAlgorithm

        //***************************************Problem Class**********************************************
        public IList<ProblemClass> ProblemClassGetAll() {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            IList<ProblemClass> problemClassList = new List<ProblemClass>();

            if (adminClient != null) {
                ProblemClass[] problemClasses = adminClient.GetProblemClasses();
                foreach (ProblemClass pc in problemClasses) {
                    problemClassList.Add(pc);
                }
            }//if (adminClient != null)

            return problemClassList;
        }//ProblemClassGetAll

        public long AddProblemClass(string name, string description) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                ProblemClass pc = new ProblemClass();
                pc.Description = description;
                pc.Name = name;

                return adminClient.AddProblemClass(pc);
            }

            return 0;
        }//AddProblemClass

        public void DeleteProblemClass(long id) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                adminClient.DeleteProblemClass(id);
            }
        }//DeleteProblemClass

        public void UpdateProblemClass(long id, string name, string description) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                ProblemClass pc = adminClient.GetProblemClass(id);
                
                if (pc != null){
                    pc.Id = id;
                    pc.Name = name;
                    pc.Description = description;

                    adminClient.UpdateProblemClass(pc);
                }
            }
        }//UpdateProblemClass

        //***************************************Problems***************************************************
        public IList<Problem> ProblemsGetAll() {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            IList<Problem> problemList = new List<Problem>();

            if (adminClient != null) {
                Problem[] problem = adminClient.GetProblems();
                foreach (Problem pr in problem) {
                    problemList.Add(pr);

                }
            }//if (adminClient != null)

            return problemList;
        }//ProblemsGetAll

        public long AddProblem(string name, string description, string dataTypeName, string dataTypeTypeName) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                Problem pr = new Problem();
                pr.DataTypeName = dataTypeName;
                pr.DataTypeTypeName = dataTypeTypeName;
                pr.Description = description;
                pr.Name = name;

                return adminClient.AddProblem(pr);
            }

            return 0;
        }//AddProblem

        public void DeleteProblem(long id) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                adminClient.DeleteProblem(id);
            }
        }//DeleteProblem

        public void UpdateProblem(long id, string name, string description, string dataTypeName, string dataTypeTypeName) {
            AdministrationServiceClient adminClient = Admin.GetClientFactory();

            if (adminClient != null) {
                Problem pr = adminClient.GetProblem(id);
                
                if (pr != null) {
                    pr.DataTypeName = dataTypeName;
                    pr.DataTypeTypeName = dataTypeTypeName;
                    pr.Description = description;
                    pr.Name = name;

                    adminClient.UpdateProblem(pr);
                }
            }
        }//UpdateProblem
    }
}